@@ -814,12 +814,12 @@ func TestVerificationContent(t *testing.T) {
 			}
 			require.NoError(t, gotErr)
 			if tt.wantCertificate {
-				require.NotNil(t, got.GetCertificate())
+				require.NotNil(t, got.Certificate())
 				return
 			}
 			if tt.wantPublicKey {
-				_, hasPubKey := got.HasPublicKey()
-				require.True(t, hasPubKey)
+				k := got.PublicKey()
+				require.NotNil(t, k)
 				return
 			}
 		})
